@@ -1,4 +1,6 @@
 import getpass
+import glob
+from typing import Iterator
 from uuid import NAMESPACE_DNS, uuid5
 
 import requests
@@ -10,7 +12,8 @@ from fhir_cli import (
     DBT_INIT_DB_TEMPLATE,
     DBT_META_TABLE,
     DBT_SCHEMA,
-    FHIR_TAG,
+    FHIR_DBT_SCHEMA,
+    FUNCTIONS_DIR_NAME,
     JINJA_ENV,
     POSTGRES_DB,
     POSTGRES_HOST,
@@ -22,6 +25,12 @@ from fhir_cli import (
 )
 
 
+def get_user_defined_functions() -> Iterator[str]:
+    for file_path in glob.iglob(f"{FUNCTIONS_DIR_NAME}/**/*.sql", recursive=True):
+        with open(file_path, "r") as f:
+            yield f.read()
+
+
 class Admin:
     """The admin command is used by an administrator to initialize a new project"""
 
@@ -66,15 +75,21 @@ class Admin:
         conn.autocommit = True
 
         project_id = uuid5(NAMESPACE_DNS, PROJECT_NAME)
-        stmt = JINJA_ENV.get_template(DBT_INIT_DB_TEMPLATE).render(
+        initdb_stmt = JINJA_ENV.get_template(DBT_INIT_DB_TEMPLATE).render(
             dbt_schema=DBT_SCHEMA,
             dbt_meta_table=DBT_META_TABLE,
             project_id=project_id,
             role=database,
         )
-        with conn.cursor() as curs:
-            curs.execute(stmt)
 
+        with conn.cursor() as curs:
+            curs.execute(initdb_stmt)
+            set_search_path_stmt = sql.SQL("SET search_path TO {dbt_schema}").format(
+                dbt_schema=sql.Identifier(DBT_SCHEMA)
+            )
+            curs.execute(set_search_path_stmt)
+            for func_definition in get_user_defined_functions():
+                curs.execute(func_definition)
         conn.close()
 
     @staticmethod
@@ -90,8 +105,7 @@ class Admin:
             postgres_port=POSTGRES_PORT,
             postgres_user=POSTGRES_USER,
             postgres_password=POSTGRES_PASSWORD,
-            dbt_schema=DBT_SCHEMA,
-            fhir_tag=FHIR_TAG,
+            schemas=",".join([FHIR_DBT_SCHEMA]),
         )
         r = requests.post(
             f"{CONNECT_URL}/connectors/",
