@@ -1,7 +1,5 @@
-import logging
-
 import fire
-from psycopg2 import ProgrammingError, connect
+from psycopg2 import ProgrammingError, connect, sql
 from psycopg2.extras import RealDictCursor
 from requests import HTTPError
 
@@ -13,6 +11,7 @@ from fhir_cli import (
     PROJECT_DB,
     PROJECT_USER,
     PROJECT_USER_PASSWORD,
+    log,
 )
 from fhir_cli.admin import Admin
 from fhir_cli.dbt import Dbt
@@ -30,12 +29,17 @@ def get_resource_from_model(model: str) -> dict:
         user=PROJECT_USER,
         password=PROJECT_USER_PASSWORD,
         cursor_factory=RealDictCursor,
+        options=f"-c search_path={DBT_SCHEMA}",
     )
+    conn.autocommit = True
+
     with conn.cursor() as curs:
         curs.itersize = 1
-        curs.execute(f"SET search_path TO {DBT_SCHEMA},{DBT_SCHEMA}_fhir")
-        curs.execute(f"SELECT {FHIR_COLUMN_NAME} FROM {model}")
-        conn.commit()
+        select_fhir_stmt = sql.SQL("SELECT {fhir_column_name} FROM {fhir_model}").format(
+            fhir_column_name=sql.Identifier(FHIR_COLUMN_NAME),
+            fhir_model=sql.Identifier(model),
+        )
+        curs.execute(select_fhir_stmt)
         row = curs.fetchone()
     conn.close()
     resource = dict_compact(row[FHIR_COLUMN_NAME])
@@ -60,15 +64,17 @@ class Cli:
         try:
             resource = get_resource_from_model(model)
         except ProgrammingError as e:
-            logging.error(e)
+            log.error(e)
             return
         fhir = FhirResource(resource)
         number_print(repr(fhir))
         try:
             fhir.validate()
-            logging.info("\U0001F525 resource is valid")
-        except (HTTPError, FhirValidationError) as e:
-            logging.error(e)
+            log.info("\U0001F525 resource is valid")
+        except HTTPError as e:
+            log.error(e.response.json())
+        except FhirValidationError as e:
+            log.error(e)
 
 
 def run():
