@@ -1,5 +1,4 @@
 import glob
-import logging
 import os
 import re
 import shutil
@@ -13,6 +12,7 @@ from fhir_cli import (
     DBT_MODELS_DIR,
     JINJA_ENV,
     MAPPING_DIR_NAME,
+    log,
 )
 
 
@@ -85,13 +85,11 @@ class Dbt:
                         try:
                             new_line = resolve_references(line)
                         except UnknownDbtReferenceError as e:
-                            logging.error(
-                                f"model {file_path} line {index + 1}:\n{line}\nError: {e}"
-                            )
+                            log.error(f"model {file_path} line {index + 1}:\n{line}\nError: {e}")
                             shutil.rmtree(DBT_MODELS_DIR)
                             return
                         except EmptyDbtReferenceWarning as e:
-                            logging.warning(
+                            log.warning(
                                 f"model {file_path} line {index + 1}:\n{line}\nWarning: {e}"
                             )
                             new_line = line
