@@ -1,5 +1,4 @@
 import json
-import logging
 
 import requests
 
@@ -50,7 +49,6 @@ class FhirResource:
         if r.status_code == 404:
             raise FhirValidationError(f"{resource_type} is an unknown resource type")
         elif r.status_code != 400 and r.status_code != 412:
-            logging.error(r.json())
             r.raise_for_status()
         data = r.json()
         issues = (
@@ -59,7 +57,7 @@ class FhirResource:
             else []
         )
         if len(issues):
-            error = "\n".join(
+            errors = "\n".join(
                 [
                     f"* {issue['location'][0]}: {issue['diagnostics']} at {issue['location'][1]}"
                     if "location" in issue
@@ -67,4 +65,4 @@ class FhirResource:
                     for issue in issues
                 ]
             )
-            raise FhirValidationError(error)
+            raise FhirValidationError(f"the FHIR server returned a list of issues\n{errors}")
